==> ocp_0.2.90.orig.tar.xz: ocp-0.2.90/playsid/libsidplayfp-git/src/sidplayfp/sidplayfp.h <==
/*
 * This file is part of libsidplayfp, a SID player engine.
 *
 * Copyright 2011-2019 Leandro Nini <drfiemost@users.sourceforge.net>
 * Copyright 2007-2010 Antti Lankila
 * Copyright 2000 Simon White
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef SIDPLAYFP_H
#define SIDPLAYFP_H

#include <stdint.h>
#include <stdio.h>
#include <vector>

#include "sidplayfp/siddefs.h"
#include "sidplayfp/sidversion.h"

class  SidConfig;
class  SidTune;
class  SidInfo;
class  EventContext;

// Private Sidplayer
namespace libsidplayfp
{
    class Player;
}

/**
 * sidplayfp
 */
class SID_EXTERN sidplayfp
{
private:
    libsidplayfp::Player &sidplayer;

public:
    sidplayfp();
    ~sidplayfp();

    /**
     * Get the current engine configuration.
     *
     * @return a const reference to the current configuration.
     */
    const SidConfig &config() const;

    /**
     * Get the current player informations.
     *
     * @return a const reference to the current info.
     */
    const SidInfo &info() const;

    /**
     * Configure the engine.
     * Check #error for detailed message if something goes wrong.
     *
     * @param cfg the new configuration
     * @return true on success, false otherwise.
     */
    bool config(const SidConfig &cfg);

    /**
     * Error message.
     *
     * @return string error message.
     */
    const char *error() const;

    /**
     * Set the fast-forward factor.
     *
     * @param percent
     */
    bool fastForward(unsigned int percent);

    /**
     * Load a tune.
     * Check #error for detailed message if something goes wrong.
     *
     * @param tune the SidTune to load, 0 unloads current tune.
     * @return true on sucess, false otherwise.
     */
    bool load(SidTune *tune);

    /**
     * Run the emulation and produce samples to play if a buffer is given.
     *
     * @param buffer pointer to the buffer to fill with samples.
     * @param count the size of the buffer measured in 16 bit samples
     *              or 0 if no output is needed (e.g. Hardsid)
     * @return the number of produced samples. If less than requested
     * and #isPlaying() is true an error occurred, use #error() to get
     * a detailed message.
     */
    uint_least32_t play(int16_t *buffer, uint_least32_t count, std::vector<int16_t *> *rawSamples = nullptr);

    /**
     * Check if the engine is playing or stopped.
     *
     * @return true if playing, false otherwise.
     */
    bool isPlaying() const;

    /**
     * Stop the engine.
     */
    void stop();

    /**
     * Control debugging.
     * Only has effect if library have been compiled
     * with the --enable-debug option.
     *
     * @param enable enable/disable debugging.
     * @param out the file where to redirect the debug info.
     */
    void debug(bool enable, FILE *out);

    /**
     * Mute/unmute a SID channel.
     *
     * @param sidNum the SID chip, 0 for the first one, 1 for the second.
     * @param voice the channel to mute/unmute.
     * @param enable true unmutes the channel, false mutes it.
     */
    void mute(unsigned int sidNum, unsigned int voice, bool enable);

    /**
     * Get the status of the given SID chip.
     *
     * @param sidNum the SID chip, 0 for the first one, 1 for the second.
     * @param gatestoggle, returns GATE changes since last time this function
     *             was called. Bit 0, if voice 1 has been enabled. Bit 1 if
     *             voice 1 has been disabled. Bit 2 and 3 for voice 2, bit
     *             4 and 5 for voice 3.
     * @param syncstoggle, returns SYNC changes since last time this function
     *             was called. Bit 0, if voice 1 has been enabled. Bit 1 if
     *             voice 1 has been disabled. Bit 2 and 3 for voice 2, bit
     *             4 and 5 for voice 3.
     * @param teststoggle, returns TEST changes since last time this function
     *             was called. Bit 0, if voice 1 has been enabled. Bit 1 if
     *             voice 1 has been disabled. Bit 2 and 3 for voice 2, bit
     *             4 and 5 for voice 3.
     * @param registers returns a pointer to an array 32 (only first 25 are
     *             needed) entries long that gives the last known write-status
     *             of the SID chip.
     * @return true on sucess, false otherwise (invalid sidNum).
     */
    bool getSidStatus(unsigned int sidNum, uint8_t& gatestoggle, uint8_t& syncstoggle, uint8_t& teststoggle, uint8_t **registers);

    /**
     * Get the current playing time.
     *
     * @return the current playing time measured in seconds.
     */
    uint_least32_t time() const;

    uint_least32_t timeMs() const;

    /**
     * Set ROM images.
     *
     * @param kernal pointer to Kernal ROM.
     * @param basic pointer to Basic ROM, generally needed only for BASIC tunes.
     * @param character pointer to character generator ROM.
     */
    void setRoms(const uint8_t* kernal, const uint8_t* basic=0, const uint8_t* character=0);

    /**
     * Get the CIA 1 Timer A programmed value.
     */
    uint_least16_t getCia1TimerA() const;
};

#endif // SIDPLAYFP_H

==> ocp-0.2.92.tar.xz: ocp-0.2.92/playsid/libsidplayfp-git/src/sidplayfp/sidplayfp.h <==
/*
 * This file is part of libsidplayfp, a SID player engine.
 *
 * Copyright 2011-2021 Leandro Nini <drfiemost@users.sourceforge.net>
 * Copyright 2007-2010 Antti Lankila
 * Copyright 2000 Simon White
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef SIDPLAYFP_H
#define SIDPLAYFP_H

#include <stdint.h>
#include <stdio.h>
#include <vector>

#include "sidplayfp/siddefs.h"
#include "sidplayfp/sidversion.h"

class  SidConfig;
class  SidTune;
class  SidInfo;
class  EventContext;

// Private Sidplayer
namespace libsidplayfp
{
    class Player;
}

/**
 * sidplayfp
 */
class SID_EXTERN sidplayfp
{
private:
    libsidplayfp::Player &sidplayer;

public:
    sidplayfp();
    ~sidplayfp();

    /**
     * Get the current engine configuration.
     *
     * @return a const reference to the current configuration.
     */
    const SidConfig &config() const;

    /**
     * Get the current player informations.
     *
     * @return a const reference to the current info.
     */
    const SidInfo &info() const;

    /**
     * Configure the engine.
     * Check #error for detailed message if something goes wrong.
     *
     * @param cfg the new configuration
     * @return true on success, false otherwise.
     */
    bool config(const SidConfig &cfg);

    /**
     * Error message.
     *
     * @return string error message.
     */
    const char *error() const;

    /**
     * Set the fast-forward factor.
     *
     * @param percent
     */
    bool fastForward(unsigned int percent);

    /**
     * Load a tune.
     * Check #error for detailed message if something goes wrong.
     *
     * @param tune the SidTune to load, 0 unloads current tune.
     * @return true on sucess, false otherwise.
     */
    bool load(SidTune *tune);

    /**
     * Run the emulation and produce samples to play if a buffer is given.
     *
     * @param buffer pointer to the buffer to fill with samples.
     * @param count the size of the buffer measured in 16 bit samples
     *              or 0 if no output is needed (e.g. Hardsid)
     * @return the number of produced samples. If less than requested
     *         and #isPlaying() is true an error occurred, use #error()
     *         to get a detailed message.
     */
    uint_least32_t play(int16_t *buffer, uint_least32_t count, std::vector<int16_t *> *rawSamples = nullptr);

    /**
     * Check if the engine is playing or stopped.
     *
     * @return true if playing, false otherwise.
     */
    bool isPlaying() const;

    /**
     * Stop the engine.
     */
    void stop();

    /**
     * Control debugging.
     * Only has effect if library have been compiled
     * with the --enable-debug option.
     *
     * @param enable enable/disable debugging.
     * @param out the file where to redirect the debug info.
     */
    void debug(bool enable, FILE *out);

    /**
     * Mute/unmute a SID channel.
     *
     * @param sidNum the SID chip, 0 for the first one, 1 for the second.
     * @param voice the channel to mute/unmute.
     * @param enable true unmutes the channel, false mutes it.
     */
    void mute(unsigned int sidNum, unsigned int voice, bool enable);

    /**
     * Get the status of the given SID chip.
     *
     * @param sidNum the SID chip, 0 for the first one, 1 for the second.
     * @param registers returns a pointer to an array 32 (only first 25 are
     *             needed) entries long that gives the last known write-status
     *             of the SID chip.
     * @return true on sucess, false otherwise (invalid sidNum).
     */
    bool getSidStatus(unsigned int sidNum, uint8_t registers[32]);

    /**
     * Get the current playing time.
     *
     * @return the current playing time measured in seconds.
     */
    uint_least32_t time() const;

    /**
     * Get the current playing time.
     *
     * @return the current playing time measured in milliseconds.
     * @since 2.0
     */
    uint_least32_t timeMs() const;

    /**
     * Set ROM images.
     *
     * @param kernal pointer to Kernal ROM.
     * @param basic pointer to Basic ROM, generally needed only for BASIC tunes.
     * @param character pointer to character generator ROM.
     */
    void setRoms(const uint8_t* kernal, const uint8_t* basic=0, const uint8_t* character=0);

    /**
     * Set the ROM banks.
     *
     * @param rom pointer to the ROM data.
     * @since 2.2
     */
    //@{
    void setKernal(const uint8_t* rom);
    void setBasic(const uint8_t* rom);
    void setChargen(const uint8_t* rom);
    //@}

    /**
     * Get the CIA 1 Timer A programmed value.
     */
    uint_least16_t getCia1TimerA() const;

    /**
     * Get the SID registers programmed value.
     *
     * @param sidNum the SID chip, 0 for the first one, 1 for the second and 2 for the third.
     * @param regs an array that will be filled with the last values written to the chip.
     * @return false if the requested chip doesn't exist.
     * @since 2.2
     */
    bool getSidStatus(unsigned int sidNum, uint8_t regs[32]);
};

#endif // SIDPLAYFP_H
